@@ -16,7 +16,7 @@ use vars qw(
 	$THIS @CONTEXT $METHOD $CALLBACK $AGAIN $SIGTHROW
 	$DEBUG_IO $DEBUG_LAMBDA $DEBUG_CALLER %DEBUG
 );
-$VERSION     = '1.25';
+$VERSION     = '1.27';
 @ISA         = qw(Exporter);
 @EXPORT_CONSTANTS = qw(
 	IO_READ IO_WRITE IO_EXCEPTION 
@@ -1204,7 +1204,7 @@ sub sysreader (){ lambda
 		my $n = sysread( $fh, $$buf, $length, length($$buf));
 		if ( $DEBUG_IO) {
 			warn "fh(", fileno($fh), ") read ", ( defined($n) ? "$n bytes" : "error $!"), "\n";
-			warn substr( $$buf, length($$buf) - $n), "\n" if $DEBUG_IO > 1 and $n > 0;
+			warn substr( $$buf, length($$buf) - $n), "\n" if $DEBUG_IO > 1 and ($n || 0) > 0;
 		}
 		return undef, $! unless defined $n;
 		return $n;
@@ -1224,7 +1224,7 @@ sub syswriter (){ lambda
 		my $n = syswrite( $fh, $$buf, $length, $offset);
 		if ( $DEBUG_IO) {
 			warn "fh(", fileno($fh), ") wrote ", ( defined($n) ? "$n bytes out of $length" : "error $!"), "\n";
-			warn substr( $$buf, $offset, $n), "\n" if $DEBUG_IO > 1 and $n > 0;
+			warn substr( $$buf, $offset, $n), "\n" if $DEBUG_IO > 1 and ($n || 0) > 0;
 		}
 		return undef, $! unless defined $n;
 		return $n;
